% Example_10_1.m: 
% This program determines a relative minimum by the
% method of steepest decent. The function is:
% f(x1,x2) = 4+4.5*x1-4*x2+x1^2+2*x2^2
%               -2*x1*x2+x1^4-2*x1^2*x2
% Note: this function has known minima at
% (x1,x2)=(1.941,3.854) and (-1.053,1.028). The
% functional values at the minima points are 0.9855 and
% -0.5134 respectively.
clear; clc;
% Define function and its partial derivatives
fx_func = @(x1,x2) 4+4.5*x1-4*x2+x1^2+2*x2^2 ...
    -2*x1*x2+x1^4-2*x1^2*x2;
dfx1_func = @(x1,x2) 4.5+2*x1-2*x2+4*x1^3-4*x1*x2;
dfx2_func = @(x1,x2) -4+4*x2-2*x1-2*x1^2;
% Define stepping parameters
ds=0.1;
max_iterations = 100;
% First guess
x1=6;
x2=10;
fx=fx_func(x1,x2);
% Print headings and initial guess to screen
fprintf('        x1         x2           fx \n');
fprintf(' 0:  %7.4f     %7.4f    %10.4f \n',x1,x2,fx);
for n=1:max_iterations
    % compute partial derivatives
    dfx1=dfx1_func(x1,x2);
    dfx2=dfx2_func(x1,x2);
    % compute magnitude of gradient
    gradf_mag=sqrt(dfx1^2+dfx2^2);
    % compute next values of x1 and x2 as per Eqn 10.4
    x1n=x1-dfx1/gradf_mag*ds;
    x2n=x2-dfx2/gradf_mag*ds;
    fxn=fx_func(x1n,x2n);
    fprintf('%2d:  %7.4f     %7.4f    %10.4f \n',...
        n,x1n,x2n,fxn);
    % if new value is larger than previous, then minimum
    % has been found
    if(fxn > fx)
        fprintf('A minimum has been found after ');
        fprintf('%d iterations\n\n',n);
        break;
        % otherwise, store new values over current ones
        % and continue
    else
        x1=x1n;
        x2=x2n;
        fx=fxn;
    end
end
if i >= max_iterations
    fprintf('Error: no solution found after ');
    fprintf('%d iterations\n',i);
else
    fmin=fx_func(x1,x2);
    fprintf('The relative minimum occurs at ');
    fprintf('x1=%.4f  x2=%.4f\n', x1,x2);
    fprintf('The minimum value for f=%.4f \n',fmin);
end
