% Example_10_8.m: This program maximizes the volume of a
% silo. The silo consists of a right cylinder topped by a
% hemisphere. The variables to optimize are radius 'R'
% and cylinder height 'L'.
% Let X(1) = R and X(2) = L.
% Eqn for surface area: S=3*pi*X(1)^2+2*pi*X(1)*X(2);
% Constraint: 3*pi*X(1)^2+2*pi*X(1)*X(2) <= 2152.6 m^2.
% We need to set up the constraint in the form:
% 3*pi*X(1)^2+2*pi*X(1)*X(2)- 2152.6 <= 0
% We wish to maximize the volume under the constraint.
% The equation for the volume, V, of the silo is given by
% V=2.0/3.0*pi*X(1)^3 + pi*X(1)^2*X(2).
% Since we wish to maximize V, we will need to place a
% minus sign in front of the expression for V and then
% minimize.
clear; clc;
global SAmax;
SAmax = 2152.6;
% Define bounds: radius and length must be positive.
LB = [0,0];
UB = [];
% Take an initial guess at the solution
Xo = [10.0 20.0];
fprintf('This program maximizes the volume of a silo\n');
fprintf('consisting of a right cylinder topped by a\n');
fprintf('hemisphere.  The maximum surface area is\n');
fprintf('fixed at %.1f m^3.\n\n',SAmax);
% Run the optimization.  We have no linear constraints,
% so pass [] for those arguments:
[X,fval]=fmincon(@objfun_silo2,...
    Xo,[],[],[],[],LB,UB,@confun_silo2);
SA = 3*pi*X(1)^2 + 2*pi*X(1)*X(2);
% Print results:
fprintf('Maximum surface area: %9.3f m^2\n',SA);
fprintf('Maximum volume:       %9.3f m^3\n',-fval);
fprintf('Optimum radius:       %9.3f m\n',X(1));
fprintf('Optimum length:       %9.3f m\n',X(2));
