% Example_10_9.m: Shaft Production Problem 
% This program maximizes the revenue/hr for the
% production of two types of shafts, type S1 and type S2.
% There are two machine shops producing these shafts,
% shop A and shop B. Each shop has two types of turning
% machines, T1 and T2, capable of producing these shafts.
% Shop A:
%   Machine T1 takes 4 minutes to produce type S1 shafts
%   and 9 minutes to produce type S2 shafts.
%   Machine T2 takes 2 minutes to produce type S1 shafts
%   and 6 minutes to produce type S2 shafts.
% Shop B:
%   Machine T1 takes 5  minutes to produce type S1 shafts
%   and 8 minutes to produce type S2 shafts.
%   Machine T2 takes 3 minutes to produce type S1 shaft
%   and 5 minutes to produce type S2 shafts. 
% Shaft S1 sells for $35 and shaft S2 sells for $85.
% We wish to determine the number of S1 & S2 shafts that
% should be produced at each shop and by each machine 
% that will maximize the revenue/hr for shaft production.
% Let: 
% X(1)=# of S1 shafts produced/hr by machine T1 at shop A 
% X(2)=# of S2 shafts produced/hr by machine T1 at shop A
% X(3)=# of S1 shafts produced/hr by machine T2 at shop A
% X(4)=# of S2 shafts produced/hr by machine T2 at shop A
% X(5)=# of S1 shafts produced/hr by machine T1 at shop B
% X(6)=# of S2 shafts produced/hr by machine T1 at shop B
% X(7)=# of S1 shafts produced/hr by machine T2 at shop B
% X(8)=# of S2 shafts produced/hr by machine T2 at shop B
% Let r=total revenue/hr for producing these shafts: 
%   r=35*(X(1)+X(3)+X(5)+X(7))+75*(X(2)+X(4)+X(6)+X(8))
clear; clc; 
% Objective function: total revenue per hour for
% manufactured shafts. Have the function return a
% negative number because we are maximizing instead of
% minimizing.
revenue=@(x) -(35*(x(1)+x(3)+x(5)+x(7))+85*(x(2)+x(4)+x(6)+x(8)));
% Take a guess at the solution
Xo = [0 0 0 0 0 0 0 0];
% Lower and upper bounds:
LB = [0 0 0 0 0 0 0 0];
UB = [];
% We have linear inequality constraints.  We require that
% each machine make an integral number of shafts per 60
% minutes, so:
%   4*X(1)+9*X(2) <= 60
%   2*X(3)+6*X(4) <= 60
%   5*X(5)+8*X(6) <= 60
%   3*X(7)+5*X(8) <= 60
A=[4 9 0 0 0 0 0 0;
   0 0 2 6 0 0 0 0;
   0 0 0 0 5 8 0 0; 
   0 0 0 0 0 0 3 5];
B=[60 60 60 60]';
% We have no linear equality constraints, so pass [] for
% those arguments.
[X, rmax] = fmincon(revenue,Xo,A,B,[],[],LB,UB);
fprintf('Optimization Results:\n\n');
fprintf('No. of S1 shafts produced at shop A ');
fprintf('by machine T1: %2.0f\n',X(1));
fprintf('No. of S2 shafts produced at shop A ');
fprintf('by machine T1: %2.0f\n',X(2));
fprintf('No. of S1 shafts produced at shop A ');
fprintf('by machine T2: %2.0f\n',X(3));
fprintf('No. of S2 shafts produced at shop A ');
fprintf('by machine T2: %2.0f\n',X(4));
fprintf('No. of S1 shafts produced at shop B ');
fprintf('by machine T1: %2.0f\n',X(5));
fprintf('No. of S2 shafts produced at shop B ');
fprintf('by machine T1: %2.0f\n',X(6));
fprintf('No. of S1 shafts produced at shop B ');
fprintf('by machine T2: %2.0f\n',X(7));
fprintf('No. of S2 shafts produced at shop B ');
fprintf('by machine T2: %2.0f\n\n',X(8));
fprintf('The max revenue per hour: $%.0f /hour\n',-rmax);
