% Example_2_25.m
% This program uses MATLAB's function interp1 to
% interpolate for the electron mobility of silicon.
% Measured values of the mobility (cm^2/V-s) vs
% temperature (K) are given [2]. Table values for
% temperature are specified in matrix T_data. Table
% values for mobility are specified in Mu_data. The
% temperature at which the electron mobility is to be
% determined is entered from the keyboard.
clear; clc;
T_data = [ 100 150 200 250 300 350 400 450 ];
Mu_data = [ 19650 7427 3723 2180 1407 972.0 705.5 531.8];
fprintf('This program interpolates for the electron\n');
fprintf('mobility (Mu) at a specified temperature T.\n');
fprintf('The valid temperature range is 100-450K.\n\n');
T=input('Enter T at which Mu is to be determined: ');
Mu = interp1(T_data,Mu_data,T);
fprintf(' T=%.1f (K)   Mu=%.3f (cm^2/V-s)\n\n', T, Mu);
% The data T_data and Mu_data can be saved in a data file
% and loaded later in another program. By the use of the
% 'clear' command the data file is removed from the
% workspace. Another script can brings the data back into
% the workspace by the load command. The script can then
% use the data for some other purpose. We want T_data and
% Mu_data to be column vectors, so save the transpose.
T_Mu_data = [T_data' Mu_data'];
save T_Mu_data;
% T_Mu_data is saved in a .mat file and will be used
% in Example 2.25.
fprintf('Mobility vs. temperature data saved to file ');
fprintf('T_Mu_data.mat\n');
clear;
% T_Mu_data has been removed from the work space
% T_Mu_data will be used in Example_2_26.
