% Example_4_1.m
% This script determines the initial zero crossing of the
% underdamped response of a parallel RLC circuit.  The
% underdamped response is:
% v(t)=exp(-t/(2RC))*(A*cos(sqrt(1/LC-(1/2RC)^2)t)
%                     + B*sin(sqrt(1/LC-(1/2RC)^2)t))
% The circuit component values and initial conditions
% are:
% R=100 ohms; L=1.0e-3 henry; C=1.0e-6 farads;
% A= 6.0 volt, B=-9.0 volt
% Solve over the interval 0 <= t <= 0.5e-3 sec
clear; clc;
R=100; L=1.0e-3; C=1.0e-6;  A=6.0; B=-9;
fprintf('Example 4.1: Find first zero crossing of ');
fprintf('underdamped RLC circuit\n');
tmin=0.0; tmax=0.5e-3;
% split up timespan into 100 intervals:
N=100;
dt=(tmax-tmin)/N;
% First, calculate t and v(t) at each timestep
for n=1:N+1
    t(n) = tmin+(n-1)*dt;
    v(n) = func_RLC(t(n),A,B,R,L,C);
    fprintf('    %10.4e       %10.3f \n',t(n),v(n));
end
plot(t,v), plot(t,v), xlabel('t'), ylabel('v'),
title('v vs t for a RLC circuit'), grid;
% Next, use the search method to find the first timestep
% where the sign of v(t) changes. When found, use fzero
% to solve.
for n=1:N
    sign = v(n)*v(n+1);
    if sign <= 0.0
        root_interval(1)=t(n);
        root_interval(2)=t(n+1);
        % Solve for the zero of the multi-argument
        % function func_RLC.m by invoking func_RLC as an
        % anonymous function of one variable.
        root = fzero(@(t) func_RLC(t,A,B,R,L,C), ...
            root_interval);
        break;
    end
end
fprintf('\n\n');
if n < N
    fprintf('First zero crossing is at t=%10.4e s\n',...
        root);
else
    fprintf('No roots lie within  %g <= t <= %g s\n',...
        tmin,tmax);
end
% Check solution. Putting root into func_RLC should
% produce zero.
v = func_RLC(root,A,B,R,L,C);
fprintf('v=%8.6e \n',v);
