% Example_5_8.m
% This program plots the electric field on the X-Z plane
% for a line charge located on the Z axis and extending
% to infinity in both Z directions. The calculation is
% made over the interval xo = [-.01,.01] m and zo = 
% [-.01,.01] m with a step size of 0.002 m.  This example
% reuses the functions already defined in Example 5.6.
clc; clear;
global xo yo zo lambda epsilon0;
lambda=2e-9; epsilon0=8.85e-12;
% for measurements on the X-Z plane, yo will always be 0:
yo=0; 
% First create a grid of X-Z locations for which
% calculate the electric field
[X,Z]=meshgrid(-10e-3:2e-3:10e-3,-10e-3:2e-3:10e-3);
% Calculate the E-field at each X-Z location, and store
% the result in the matrices Ex and Ez
for i=1:length(X(:,1))
    for j=1:length(Z(1,:))
        xo=X(i,j);
        zo=Z(i,j);
        % NOTE: don't calculate the field when situated
        % ON the line charge because it will be infinity.
        % Instead, use the value "NaN" (which will cause
        % no point to be printed on the quiver plot).
        if xo==0
            Ex(i,j)=NaN;
            Ez(i,j)=NaN;
        else
            Ex(i,j)=quad(@linecharge_Ex,-10,10);
            Ez(i,j)=quad(@linecharge_Ez,-10,10);
        end
    end
end
% Plot the electric field
quiver(X,Z,Ex,Ez);
title('E-field due to a line charge along the Z axis');
xlabel('x axis');
ylabel('z axis');
