% hemisphere_dV.m: This function defines the integrand
% z(x,y) for determining the volume of a hemisphere and
% is used in MATLABs dblquad function. From analytical
% geometry, the equation of a sphere is X^2 + Y^2 + Z^2 =
% R^2. Thus, dV=Z*dX*dY, where Z=sqrt(R^2-X^2-Y^2). Note
% that the hemisphere is only defined for (X,Y) points
% which lie within a circle of radius R around the
% origin, the region that is the projection of the
% hemisphere onto the X-Y plane. An 'if' statement is
% used to set Z = 0 for (X,Y) points outside the circle
% of radius R. Note: X is a vector and Y is a scalar.
function Z = hemisphere_dV(X,Y)
global R;
for i=1:length(X)
    if X(i)^2 + Y^2 <= R^2
        Z(i) = sqrt(R^2 - X(i)^2 - Y^2);
    else
        Z(i) = 0;
    end
end
