% Example_6_2.m
% Calculate ramp response of RC circuit via two methods:
% 1. exact solution
% 2. Runge-Kutta method
clc; clear;
% circuit parameters
R=1e3;      % ohms
C=1e-6;     % farads
tau = R*C;  % seconds
Vo = 10;    % volts
f = @(tm,Vc) 1/tau*(Vo*tm-Vc);  % Equation 6.16
% parameters for Euler algorithm
interval = 10*tau;
steps = [20 6];
for j=1:length(steps)
    h = interval/steps(j);
    % create set of time points to calculate
    t = 0:h:interval;
    Vc_exact = zeros(length(t),1);
    Vc_RK = zeros(length(t),1);
    % initial conditions
    Vc_exact(1)=0;
    Vc_RK(1)=0;
    for i=1:length(t)-1
        % Calculate exact solution
        Vc_exact(i+1) = Vo ...
            * (t(i+1)-tau+tau*exp(-t(i+1)/tau));
        % Calculate Runge-Kutta solution
        k1=f(t(i),Vc_RK(i));
        k2=f(t(i)+h/2,Vc_RK(i)+h/2*k1);
        k3=f(t(i)+h/2,Vc_RK(i)+h/2*k2);
        k4=f(t(i+1),Vc_RK(i)+h*k3);
        Vc_RK(i+1)=Vc_RK(i)+h/6*(k1+2*k2+2*k3+k4);
    end      
    % plot results
    subplot(1,length(steps),j)
    plot(t,Vc_RK,'x',t,Vc_exact),
    legend('Runge-Kutta','Exact','Location','NorthWest');
    title('Ramp Response for RC circuit');
    xlabel('seconds'), ylabel('Vc (volts)');
    text(0.005,0.005,sprintf('%d steps',steps(j))); 
    % calculate global error
    global_error_RK = abs((Vc_exact -Vc_RK) ./ Vc_exact);
    fprintf('Worst case global percent error for ');
    fprintf('Runge-Kutta for %2d steps: %4.2f %%\n',...
        steps(j),100*max(global_error_RK));               
end
