% Example_6_4.m
% This program solves a single second order ordinary
% differential equation by the Runge-Kutta Method.  The
% differential equation describes the capacitor voltage
% in a series RLC circuit
clear; clc;
% Component values:
R=10; L=1.0e-3; C=2.0e-6;
% Initial conditions:
vc(1)=0; v2(1)=6* sqrt(1/(L*C));
% Define time interval and step size.  Since the natural
% frequency sqrt(1/LC) is 3559 Hz, choose a time interval
% to capture several oscillations. 3559 Hz has period of
% 281 usec, so choose 1000 usec for interval.
tmax=1000e-6; steps=100; h=tmax/steps;
t=0:h:tmax;
% Define v2' = f(t,x,y):
v2_prime = @(t,x,y) -(1/(L*C))*x - (R/L)*y;
% Do Runge-Kutta algorithm:
for i=1:steps
    K1=v2_prime(t(i), vc(i), v2(i));
    L1=v2(i);
    K2=v2_prime(t(i), vc(i)+h/2*L1, v2(i)+h/2*K1);
    L2=v2(i)+h/2*K1;
    K3=v2_prime(t(i), vc(i)+h/2*L2, v2(i)+h/2*K2);
    L3=v2(i)+h/2*K2;
    K4=v2_prime(t(i), vc(i)+h*L3, v2(i)+h*K3);
    L4=v2(i)+h*K3;
    vc(i+1)=vc(i)+h/6*(L1+2*L2+2*L3+L4);
    v2(i+1)=v2(i)+h/6*(K1+2*K2+2*K3+K4);
end
% Calculate exact solution
beta = v2(1) / sqrt( 1/(L*C) - (R/(2*L))^2);
vc_exact = exp(-R/(2*L) * t)* beta ...
    .* sin(sqrt( 1/(L*C) - (R/(2*L))^2)*t );
% Print results to screen.
fprintf('Runge-Kutta solution for a single ');
fprintf('second order ODE:\n\n');
fprintf('    t       R-K Sol''n   Exact Sol''n\n');
fprintf('-------------------------------------\n');
for i=1:10:steps+1  % just print every tenth step
    fprintf('%10.3e  %8.4f   %8.4f \n', ...
        t(i),vc(i), vc_exact(i));
end
% Plot results:
plot(t,vc_exact,t,vc,'x');
xlabel('t (seconds)'), ylabel('volts');
title('Capacitor voltage of series RLC circuit');
legend('Exact','Runge-Kutta');
