% Example_6_6.m
% Solve a system of two first-order ordinary differential
% equations (Equations 2.6 and 2.7).
% Assume: y(1)=v and y(2)=iL
% Assume: R=50, L=1e-6, C=10e-9, v(t=0)=3.3, i(t=0)=0.
% Equation 2.6: yprime(2) = (1/L)*y(1)
% Equation 2.7: yprime(1) = -1/(R*C)*y(1) - (1/C)*y(2)
clear; clc;
initial=[3.3 0];
tspan=0:.01e-6:4e-6;
[ t,y ] = ode45('dydt_rlc',tspan,initial);
v = y(:,1);
iL = y(:,2);
fprintf('      t               v           iL   \n');
fprintf('---------------------------------------\n');
% print every tenth value of v and iL
for i=1:10:length(t)
    fprintf(' %1.10f   %10.4f   %10.4f  \n', ...
        t(i),v(i),iL(i));
end
% Plot v and iL together.  Use plotyy() to create a
% second 'y' axis on the right side.  plotyy() returns
% graphics handles to the axes and lines so that their
% style can be adjusted.
[ axis,line1,line2 ] = plotyy(t,v,t,iL);
xlabel('t'), ylabel('v (volts)');
title('v and iL vs. t'), grid;
% set label for right 'y' axis
set(get(axis(2),'Ylabel'),'String','i_L (amps)');
% plot iL with a dashed line
set(line2,'LineStyle','--');
legend('v','i_L');
