% Example_7_4.m: This program solves Equation 7.26 by
% converting it into a system of two differential
% equations and solving with ode45.
% Let v=y', Y=[y v], and Y'=[y' v'].
% Y(1)=y, Y(2)=v, Y'(1)=Y(2), Y'(2)=5*sin 2t-3Y(2)-2Y(1)
% Initial conditions: y(0)=1.0, y'(0)=v(0)=-4.0
clear; clc;
% Define initial conditions:
Y0=[1.0 -4.0];
% Define time interval to solve:
dt=0.1; Tstop=10; Tspan=0.0:dt:Tstop;
% solve the ODE directly with ode45:
[t,Yode45]=ode45('dydt',Tspan,Y0);
% compute the solution found via Laplace Transforms
%(Equation 7.32):
Ylaplace = 1.75*exp(-2*Tspan) ...
    - 0.75*cos(2*Tspan) - 0.25*sin(2*Tspan);
plot(t,Yode45(:,1),'x',Tspan,Ylaplace),
axis([0 Tstop -1 1]);
xlabel('t') ,ylabel('Yode45, Ylaplace');
title('ODE solutions using ode45 and Laplace Transform');
legend('ode45','Laplace','Location','SouthWest');
