% Example_8_2.m
% Compute normalized exponential Fourier series
% coefficients for a pulse train
tau = 0.25e-3;           % "on" time of a single pulse
T = [ 1e-3 2e-3 10e-3 ]; % pulse train periods
fo = 1 ./ T;             % frequency of pulse train in Hz
n = -150:150;
for i=1:length(T)
    Cn(i,:) = ( 1 ./ (pi*n) ) .* sin(pi*n*fo(i)*tau);
    % Find the "zero" entry in n and compute it
    % separately (because it has a different formula than
    % the rest):
    zeroeth_element = find(n==0);
    Cn(i,zeroeth_element) = tau/T(i);
    % Normalize the coefficients:
    Cn_normalized(i,:) = Cn(i,:) .* T(i);
end
% find reasonable limits for axes so that all 3 plots
% have the same min/max
x_axis_limits = [ -3.8/tau 3.8/tau];
y_axis_limits = [ 1.5*min(Cn_normalized(1,:)) ...
    1.25*max(Cn_normalized(1,:)) ];
% Plot separately for each value of T:
subplot(3,1,1);
stem( n*fo(1), Cn_normalized(1,:) );
ylabel({'Fourier coefficients';'for T=1 ms'});
axis([x_axis_limits y_axis_limits]);
title('Exponential Fourier Series for Pulse');
subplot(3,1,2);
stem( n*fo(2), Cn_normalized(2,:) );
axis([x_axis_limits y_axis_limits]);
ylabel({'Fourier coefficients';'for T=2 ms'});
subplot(3,1,3);
plot( n*fo(3), Cn_normalized(3,:) );
axis([x_axis_limits y_axis_limits]);
ylabel({'Fourier coefficients';'for T=10 ms'});
xlabel('f (Hz)');
