% Example_9_3.m
% This program uses interpolation by cubic splines to
% upsample an audio signal.
clear; clc;
% Define original data points for y(t) (time in microsec)
orig_t=[0  4  8 12 16 20 24  28  32  36 40  44 48 52 56];
orig_y=[.7 .9 .9 .7 .3 0 -.3 -.7 -.7 -.3 0  .3 .7 .7 .3];
% Define upsampled time points
upsampled_t = 0:60;
% Calculate interpolated data points using cubic splines
interp_y = interp1(orig_t,orig_y,upsampled_t,'spline');
% Print output to screen
fprintf('UPSAMPLING VIA CUBIC SPLINE FIT\n');
fprintf('time (microsec)  orig sample  upsample\n');
fprintf('--------------------------------------\n');
for i=1:length(upsampled_t)
    % Try to find the corresponding timepoint in the
    % original dataset for this upsampled timepoint with
    % MATLAB's "find" function.
    j = find(orig_t == upsampled_t(i));
    if j>0
        % if we found original value, print both orig and
        % interpolated.
        fprintf('%8.2f      %10.1f   %10.3f\n', ...
            upsampled_t(i),orig_y(j),interp_y(i));
    else
        % otherwise, just print interpolated value
        fprintf('%8.2f                   %10.3f \n', ...
            upsampled_t(i),interp_y(i));
    end
end
plot(orig_t,orig_y,'o',upsampled_t,interp_y);
xlabel('t (microsec)'); ylabel('y(t)'); grid;
title('Upsampling with Cubic Spline Interpolation');
legend('original','upsampled','Location','SouthWest');
